@@ -1,5 +1,5 @@
 test_that("good input", {
-  mock_res = structure(
+  mock_res <- structure(
     list(),
     class = "gh_response",
     response = list(
@@ -9,7 +9,7 @@ test_that("good input", {
     )
   )
 
-  limit = gh_rate_limit(mock_res)
+  limit <- gh_rate_limit(mock_res)
 
   expect_equal(limit$limit, 5000L)
   expect_equal(limit$remaining, 4999L)
@@ -18,18 +18,17 @@ test_that("good input", {
 
 test_that("errors", {
   expect_error(gh_rate_limit(list()))
-  expect_error(gh_rate_limit(.token = "bad"))
+  expect_error(gh_rate_limits(.token = "bad"))
 })
 
 test_that("missing rate limit", {
-  mock_res = structure(
+  mock_res <- structure(
     list(),
     class = "gh_response",
-    response = list(
-    )
+    response = list()
   )
 
-  limit = gh_rate_limit(mock_res)
+  limit <- gh_rate_limit(mock_res)
 
   expect_equal(limit$limit, NA_integer_)
   expect_equal(limit$remaining, NA_integer_)
